#
# spec file for package xcalib
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xcalib
Version:        0.10
Release:        1.17
Summary:        Load ICC profile calibration part to graphics card
License:        GPL-2.0-or-later
Group:          System/X11/Utilities
URL:            https://github.com/OpenICC/xcalib
Source0:        https://github.com/OpenICC/xcalib/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  color-filesystem
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xxf86vm)
%if "%{_repository}" == "SUSE_Linux_10.1" || "%{_repository}" == "SLE_10"
BuildRequires:  pkgconfig
BuildRequires:  xorg-x11-compat70-devel
%endif

%description
The command line tool applies the 'vcgt'-tag of ICC profiles to your X-server
like MS-Windows or MacOS can to set your display to a calibrated state.

Versions 0.5 and higher are also usable with Microsoft Windows.
They can be used as a free alternative to other calibration loaders.

%package profiles
Summary:        ICC profiles for testing with xcalib
Group:          Productivity/Graphics/Other

%description profiles
The ICC profiles are special for testing xcalib.

%prep
%setup -q

%build
%cmake
%cmake_build

%install
%cmake_install
rm -fv %{buildroot}%{_datadir}/color/icc/xcalib/test/Adobe*.icm

%files
%defattr(0644,root,root, 0755)
%license COPYING
%doc README.md README.profilers
%defattr(0755,root,root)
%{_bindir}/xcalib
%defattr(0644,root,root)
%{_mandir}/man1/xcalib.1%{?ext_man}

%files profiles
%license COPYING
%doc README.md README.profilers
%{_datadir}/color/icc/xcalib/test/bluish.icc
%{_datadir}/color/icc/xcalib/test/gamma_1_0.icc
%{_datadir}/color/icc/xcalib/test/gamma_2_2_bright.icc
%{_datadir}/color/icc/xcalib/test/gamma_2_2.icc
%{_datadir}/color/icc/xcalib/test/gamma_2_2_lowContrast.icc
%dir %{_datadir}/color/icc/xcalib
%dir %{_datadir}/color/icc/xcalib/test

%changelog
* Mon Feb  8 2021 Dirk Müller <dmueller@suse.com>
- update to 0.10:
  * rename -s to -o option
  * Fix incorrect use of X11 screen and output
* Tue Nov 28 2017 crrodriguez@opensuse.org
- Cleanup BuildRequires so only what is actually required
  is pulled for build.
* Sun Jan  1 2017 jengelh@inai.de
- Trim %%clean, authors, and move stray export command to %%build
  section where it makes more sense.
* Thu Jun 30 2016 Kai-Uwe Behrmann <ku.b@gmx.de>
- remove _service to appeace the factory gate keeper
- remove xcalib.1.patch, it is included in the release
- remove xcalib-makefile.patch, makefile is not used
* Tue May 26 2015 Kai-Uwe Behrmann <ku.b@gmx.de>
- try to fix build script for Arch_Extra
* Wed Nov 26 2014 Kai-Uwe Behrmann <ku.b@gmx.de>
- try to fix buildrequires for ScientificLinux_7
* Wed Nov 26 2014 Kai-Uwe Behrmann <ku.b@gmx.de>
- fix buildrequires for SLES
* Wed Nov 26 2014 Kai-Uwe Behrmann <ku.b@gmx.de>
- fix buildrequires for RH/CentOS
* Wed Nov 26 2014 Kai-Uwe Behrmann <ku.b@gmx.de>
- update to 0.9.0
- use cmake build system
- change profile install path to be more package specific
- move man page to package
- add XRandR support
- fix rounding errors
* Sun Sep 28 2014 Kai-Uwe Behrmann <ku.b@gmx.de>
- add Arch PKGBUILD
* Sat Sep 27 2014 Kai-Uwe Behrmann <ku.b@gmx.de>
- fix spec file to compile CentOS and RHEL
* Thu Dec  8 2011 coolo@suse.com
- this should be GPL-2.0+, GPL is not a license on spdx.org
* Wed Sep 21 2011 Kai-Uwe Behrmann <ku.b@gmx.de> - 0.4.2
- add spec license
- remove name, version and revision macros
- add man page from debian project
  * Fri Dec 26 2008 - P. Linnell mrdocs at opensuse.org
- spec file cleanups
  * Thu Apr 24 2008 - P. Linnell <mrodcs at scribus.info>
- fix build on CentOS and RHEL
  * Mon Aug 27 2007 - P. Linnell <mrodcs at scribus.info>
- 0.8 release
-applied gl.tter's patch for Win32 multi-monitor support
-applied bleader's patch for FGLRX multi-monitor support
-added support for LUTs bigger than in the profile linear interpolation is used for creating the values in between
-Cchanged -n parameter: now the size of the simulated LUT must be given after -n/-noaction paramter
  * Sun Jul 29 2007  - P. Linnell <mrodcs at scribus.info>
- try to fix more cross platform BuildRequires
  * Sun Jun 24 2007  - P. Linnell <mrodcs at scribus.info>
- first build server package
- make 2nd package with the profiles in openicc directory
